gsprofilesrv_plat/settings_framework_api/inc/GSMainView.h
branchRCL_3
changeset 11 23553eb4e470
parent 8 f62c3a3d66b8
--- a/gsprofilesrv_plat/settings_framework_api/inc/GSMainView.h	Fri Mar 12 15:43:47 2010 +0200
+++ b/gsprofilesrv_plat/settings_framework_api/inc/GSMainView.h	Mon Mar 15 12:41:46 2010 +0200
@@ -91,6 +91,26 @@
         * are changed.
         */
         void UpdateView();
+        
+        /**
+         * represent the position of ListBox
+         */
+        struct TListBoxPosition
+		    {
+		    /**
+		     * The three items are all set to -1 as an initial value because their legal
+		     * value should be no less than 0.
+		     */
+		    inline void Reset()
+		    	{
+		        iCurrentItemIndex = -1;
+		    	iItemOffsetInPixels = -1;
+		    	iTopItemIndex = -1;
+		    	}
+		    TInt iCurrentItemIndex;
+		    TInt iItemOffsetInPixels;
+		    TInt iTopItemIndex;
+		    };
 
     public: // From CAknView
 
@@ -183,12 +203,13 @@
         TUid iSelectedPluginUid;
         
         //keep the exact position of the listbox including current item index,
-        //iVerticalOffset and  TopItemindex
-        RArray<TInt> iPosition;
+        //ItemOffsetInPixels and  TopItemindex
+        TListBoxPosition iPosition;
         
         //record the screen mode, portrait/landscape
-        TBool iScreenMode;
+        TBool iIsLandscapeOrientation;
     };
 
+
 #endif  // GSMAINVIEW_H
 // End of File